@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-07-08'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-08-01'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -185,7 +185,7 @@ my $header_line = <$fh>;
             $content =~ s/^ //gm;
             $content = "# line ".($data_linepos + 1 + keys(%$toc) + 1 + $order+1 + $lineoffset)." \"".__FILE__."\"\n" . $content;
             open my $fh, '<', \$content
-                or die "DataPacker error loading $_[1] (could be a perl installation issue?)";
+                or die "DataPacker error loading $_[1]: $!";
             return $fh;
         }
         return;
@@ -244,7 +244,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.08 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-07-08.
+This document describes version 0.09 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-08-01.
 
 =head1 SEE ALSO
 
@@ -259,8 +259,9 @@ L<datapack-modules>, CLI for C<datapack_modules>.
 
 =head2 datapack_modules(%args) -> [status, msg, result, meta]
 
-Like Module::FatPack, but uses datapacking instead of fatpack.
+{en_US Like Module::FatPack, but uses datapacking instead of fatpack}.
 
+{en_US 
 Both this module and C<Module:FatPack> generate source code that embeds modules'
 source codes and load them on-demand via require hook. The difference is that
 the modules' source codes are put in C<__DATA__> section instead of regular Perl
@@ -276,6 +277,7 @@ section is not yet available. You can only use run-time require()'s.
 
 Another downside of this technique is that you cannot use C<__DATA__> section for
 other purposes (well, actually with some care, you still can).
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -283,51 +285,51 @@ Arguments ('*' denotes required arguments):
 
 =item * B<module_names> => I<array[str]>
 
-Module names to search.
+{en_US Module names to search}.
 
 =item * B<module_srcs> => I<hash>
 
-Module source codes (a hash, keys are module names).
+{en_US Module source codes (a hash, keys are module names)}.
 
 =item * B<output> => I<str>
 
-Output filename.
+{en_US Output filename}.
 
 =item * B<overwrite> => I<bool> (default: 0)
 
-Whether to overwrite output if previously exists.
+{en_US Whether to overwrite output if previously exists}.
 
 =item * B<postamble> => I<str>
 
-Perl source code to add after the datapack code (but before the __DATA__ section).
+{en_US Perl source code to add after the datapack code (but before the __DATA__ section)}.
 
 =item * B<preamble> => I<str>
 
-Perl source code to add before the datapack code.
+{en_US Perl source code to add before the datapack code}.
 
 =item * B<stripper> => I<bool> (default: 0)
 
-Whether to strip included modules using Perl::Stripper.
+{en_US Whether to strip included modules using Perl::Stripper}.
 
 =item * B<stripper_comment> => I<bool> (default: 1)
 
-Set strip_comment=1 (strip comments) in Perl::Stripper.
+{en_US Set strip_comment=1 (strip comments) in Perl::Stripper}.
 
 =item * B<stripper_log> => I<bool> (default: 0)
 
-Set strip_log=1 (strip log statements) in Perl::Stripper.
+{en_US Set strip_log=1 (strip log statements) in Perl::Stripper}.
 
 =item * B<stripper_maintain_linum> => I<bool> (default: 0)
 
-Set maintain_linum=1 in Perl::Stripper.
+{en_US Set maintain_linum=1 in Perl::Stripper}.
 
 =item * B<stripper_pod> => I<bool> (default: 1)
 
-Set strip_pod=1 (strip POD) in Perl::Stripper.
+{en_US Set strip_pod=1 (strip POD) in Perl::Stripper}.
 
 =item * B<stripper_ws> => I<bool> (default: 1)
 
-Set strip_ws=1 (strip whitespace) in Perl::Stripper.
+{en_US Set strip_ws=1 (strip whitespace) in Perl::Stripper}.
 
 =back
 
